package com.srs.comprehensive.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.comprehensive.domain.Questionnaire;

/**
 * 问卷调查Mapper接口
 *
 * @author srs
 * @date 2024-05-18
 */
public interface QuestionnaireMapper extends BaseMapper<Questionnaire> {
    /**
     * 查询问卷调查
     *
     * @param id 问卷调查主键
     * @return 问卷调查
     */
    public Questionnaire selectQuestionnaireById(Long id);

    /**
     * 查询问卷调查列表
     *
     * @param questionnaire 问卷调查
     * @return 问卷调查集合
     */
    List<Questionnaire> selectQuestionnaireList(Questionnaire questionnaire);

    /**
     * 新增问卷调查
     *
     * @param questionnaire 问卷调查
     * @return 结果
     */
    int insertQuestionnaire(Questionnaire questionnaire);

    /**
     * 修改问卷调查
     *
     * @param questionnaire 问卷调查
     * @return 结果
     */
    int updateQuestionnaire(Questionnaire questionnaire);

    /**
     * 删除问卷调查
     *
     * @param id 问卷调查主键
     * @return 结果
     */
    int deleteQuestionnaireById(Long id);

    /**
     * 批量删除问卷调查
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteQuestionnaireByIds(Long[] ids);

    int insertRelease(Questionnaire questionnaire);

    boolean saveBatchCustom(List<Questionnaire> list);

}
